Learn R Programming

RadioGx (version 0.0.2)

showSigAnnot: Show the Annotations of a signature object

Description

This funtion prints out the information about the call used to compute the rad signatures, and the session info for the session in which the computation was done. Useful for determining the exact conditions used to generate signatures.

Usage

showSigAnnot(Sigs)

Arguments

Sigs

An object of the RadioSig Class, as returned by radPerturbationSig or radSensitivitySig

Value

Prints the RadioGx Signatures annotations to the output stream, and returns invisible NULL.

Examples

Run this code
# NOT RUN {
data(Cleveland_small)
rad.sensitivity <- radSensitivitySig(Cleveland_small, mDataType="rna",
             nthread=1, features = fNames(Cleveland_small, "rna")[1])
showSigAnnot(rad.sensitivity)

# }

Run the code above in your browser using DataLab